@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2016-12-17'; # DATE
-our $VERSION = '1.67'; # VERSION
+our $DATE = '2016-12-29'; # DATE
+our $VERSION = '1.68'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1220,31 +1220,49 @@ sub parse_cmdline_src {
 }
 
 # determine filehandle to output to (normally STDOUT, but we can also send to a
-# pager
+# pager, or a temporary file when sending to viewer (the difference between
+# pager and viewer: when we page we use pipe, when we view we write to temporary
+# file then open the viewer. viewer settings override pager settings.
 sub select_output_handle {
     my ($self, $r) = @_;
 
     my $resmeta = $r->{res}[3] // {};
 
     my $handle;
-    if ($resmeta->{"cmdline.page_result"}) {
-        require File::Which;
-        my $pager = $resmeta->{"cmdline.pager"} //
-            $ENV{PAGER};
-        unless (defined $pager) {
-            $pager = "less -FRSX" if File::Which::which("less");
+  SELECT_HANDLE:
+    {
+        # view result using external program
+        if ($ENV{VIEW_RESULT} // $resmeta->{"cmdline.view_result"}) {
+            my $viewer = $resmeta->{"cmdline.viewer"} // $ENV{VIEWER} //
+                $ENV{BROWSER};
+            last if defined $viewer && !$viewer; # ENV{VIEWER} can be set 0/'' to disable viewing result using external program
+            die [500, "No VIEWER program set"] unless defined $viewer;
+            $r->{viewer} = $viewer;
+            require File::Temp;
+            my $filename;
+            ($handle, $filename) = File::Temp::tempfile();
+            $r->{viewer_temp_path} = $filename;
         }
-        unless (defined $pager) {
-            $pager = "more" if File::Which::which("more");
+
+        if ($ENV{PAGE_RESULT} // $resmeta->{"cmdline.page_result"}) {
+            require File::Which;
+            my $pager = $resmeta->{"cmdline.pager"} //
+                $ENV{PAGER};
+            unless (defined $pager) {
+                $pager = "less -FRSX" if File::Which::which("less");
+            }
+            unless (defined $pager) {
+                $pager = "more" if File::Which::which("more");
+            }
+            unless (defined $pager) {
+                die [500, "Can't determine PAGER"];
+            }
+            last unless $pager; # ENV{PAGER} can be set 0/'' to disable paging
+            #$log->tracef("Paging output using %s", $pager);
+            open $handle, "| $pager";
         }
-        unless (defined $pager) {
-            die [500, "Can't determine PAGER"];
-        }
-        last unless $pager; # ENV{PAGER} can be set 0/'' to disable paging
-        #$log->tracef("Paging output using %s", $pager);
-        open $handle, "| $pager";
+        $handle //= \*STDOUT;
     }
-    $handle //= \*STDOUT;
     $r->{output_handle} = $handle;
 }
 
@@ -1284,6 +1302,11 @@ sub display_result {
         }
     } else {
         print $handle $fres;
+        if ($r->{viewer}) {
+            require ShellQuote::Any::Tiny;
+            my $cmd = $r->{viewer} ." ". ShellQuote::Any::Tiny::shell_quote($r->{viewer_temp_path});
+            system $cmd;
+        }
     }
 }
 
@@ -1456,6 +1479,54 @@ sub run {
     }
 }
 
+# BEGIN FATPACK CODE: ShellQuote/Any/Tiny.pm
+{
+    no strict 'refs';
+    $main::fatpacked{"ShellQuote/Any/Tiny.pm"} = '##line '.(1+__LINE__).' "'.__FILE__."\"\n".<<'SHELLQUOTE_ANY_TINY';
+#package ShellQuote::Any::Tiny;
+#
+#our $DATE = '2016-12-27';
+#our $VERSION = '0.003';
+#
+#use strict;
+#use warnings;
+#
+#use Exporter qw(import);
+#our @EXPORT_OK = qw(shell_quote);
+#
+#sub shell_quote {
+#    my $arg = shift;
+#
+#    if ($^O eq 'MSWin32') {
+#        if ($arg =~ /\A\w+\z/) {
+#            return $arg;
+#        }
+#        $arg =~ s/([\\"])/\\$1/g;
+#        return qq("$arg");
+#    } else {
+#        if ($arg =~ /\A\w+\z/) {
+#            return $arg;
+#        }
+#        $arg =~ s/'/'"'"'/g;
+#        return "'$arg'";
+#    }
+#}
+#
+#1;
+#
+#__END__
+#
+SHELLQUOTE_ANY_TINY
+
+    $main::fatpacked{$_} =~ s/^\#//mg for ('ShellQuote/Any/Tiny.pm');
+    my $class = 'FatPacked::'.(0+\%main::fatpacked);
+    unless (defined &{"${class}::INC"}) { if ($] < 5.008) { *{"${class}::INC"} = sub { if (my $fat = $_[0]{$_[1]}) { return sub { return 0 unless length $fat; $fat =~ s/^([^\n]*\n?)//; $_ = $1; return 1; }; } return; }; } else { *{"${class}::INC"} = sub { if (my $fat = $_[0]{$_[1]}) { open my $fh, '<', \$fat or die "FatPacker error loading $_[1] (could be a perl installation issue?)"; return $fh; } return; }; } }
+    my $hook = bless(\%main::fatpacked, $class);
+    push @INC, $hook unless grep {ref($_) && "$_" eq "$hook"} @INC;
+}
+# END OF FATPACK CODE
+
+
 1;
 # ABSTRACT: Base class for Perinci::CmdLine{::Classic,::Lite}
 
@@ -1471,7 +1542,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.67 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-12-17.
+This document describes version 1.68 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-12-29.
 
 =head1 DESCRIPTION
 
@@ -1735,6 +1806,15 @@ can also be pipe to pager (if paging is turned on).
 
 Set to true if user specifies C<--naked-res>.
 
+=item * viewer => str
+
+Program to use as external viewer.
+
+=item * viewer_temp_path => str
+
+Set to temporary filename created to store the result to view to external viewer
+program.
+
 =back
 
 =head1 HOOKS
@@ -1907,6 +1987,21 @@ For example:
 Instruct to use specified pager instead of C<$ENV{PAGER}> or the default C<less>
 or C<more>.
 
+=head2 attribute: cmdline.view_result => bool
+
+Aside from using a pager, you can also use a viewer. The difference is, when we
+use a pager we pipe the output directly to the pager, but when we use a viewer
+we write to a temporary file then call the viewer with that temporary filename
+as argument. Viewer settings override pager settings.
+
+If this attribute is set to true, will view result using external viewer
+(external viewer program is set either from C<cmdline.viewer> or C<VIEWER> or
+C<BROWSER>. An error is raised when there is no viewer set.)
+
+=head2 attribute: cmdline.viewer => STR
+
+Instruct to use specified viewer instead of C<$ENV{VIEWER}> or C<$ENV{BROWSER}>.
+
 =head2 attribute: cmdline.skip_format => bool (default: 0)
 
 When we want the command-line framework to just print the result without any
@@ -2324,6 +2419,23 @@ Called by parse_argv() or do_completion(). Subclass has to implement this.
 
 =head1 ENVIRONMENT
 
+=head2 VIEW_RESULT => bool
+
+Can be set to 1 to force using viewer to view result. Can be set to 0 to
+explicitly disable using viewer to view result even though
+C<cmdline.view_result> result metadata attribute is active.
+
+=head2 VIEWER => str
+
+Can be set to select the viewer program to override C<cmdline.viewer>. Can also
+be set to C<''> or C<0> to explicitly disable using viewer to view result even
+though C<cmdline.view_result> result metadata attribute is active.
+
+=head2 PAGE_RESULT => bool
+
+Can be set to 1 to force paging of result. Can be set to 0 to explicitly disable
+paging even though C<cmd.page_result> result metadata attribute is active.
+
 =head2 PAGER => str
 
 Like in other programs, can be set to select the pager program (when
@@ -2331,6 +2443,11 @@ C<cmdline.page_result> result metadata is active). Can also be set to C<''> or
 C<0> to explicitly disable paging even though C<cmd.page_result> result metadata
 is active.
 
+=head2 BROWSER => str
+
+When VIEWER is not set, then this environment variable will be used to select
+external viewer program.
+
 =head2 PERINCI_CMDLINE_PROGRAM_NAME => STR
 
 Can be used to set CLI program name.
