@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2016-12-17'; # DATE
-our $VERSION = '1.67'; # VERSION
+our $DATE = '2016-12-29'; # DATE
+our $VERSION = '1.68'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -57,7 +57,7 @@ has validate_args => (
     default => 1,
 );
 
-my $formats = [qw/text text-simple text-pretty json json-pretty csv/];
+my $formats = [qw/text text-simple text-pretty json json-pretty csv html html+datatables/];
 
 sub BUILD {
     my ($self, $args) = @_;
@@ -289,6 +289,12 @@ sub hook_format_result {
 
     my $fmt = $r->{format} // 'text';
 
+    if ($fmt eq 'html+datatables') {
+        $fmt = 'text-pretty';
+        $ENV{VIEW_RESULT} = 1;
+        $ENV{FORMAT_PRETTY_TABLE_BACKEND} = 'Text::Table::HTML::DataTables';
+    }
+
     my $fres = Perinci::Result::Format::Lite::format(
         $r->{res}, $fmt, $r->{naked_res});
 
@@ -503,7 +509,7 @@ sub action_call {
 }
 
 1;
-# ABSTRACT: A lightweight Rinci/Riap-based command-line application framework
+# ABSTRACT: A Rinci/Riap-based command-line application framework
 
 __END__
 
@@ -513,11 +519,11 @@ __END__
 
 =head1 NAME
 
-Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application framework
+Perinci::CmdLine::Lite - A Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.67 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2016-12-17.
+This document describes version 1.68 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2016-12-29.
 
 =head1 SYNOPSIS
 
@@ -638,9 +644,12 @@ See L<Perinci::CmdLine::Manual> for more details.
 There is also a blog post series on Perinci::CmdLine tutorial:
 L<https://perlancar.wordpress.com/category/pericmd-tut/>
 
-Perinci::CmdLine::Lite is the default backend implementation. You normally
-should use L<Perinci::CmdLine::Any> instead to be able to switch backend on the
-fly.
+Perinci::CmdLine::Lite is the default backend implementation. Another
+implementation is the heavier L<Perinci::CmdLine::Classic> which has a couple of
+more features not yet incorporated into ::Lite, e.g. transactions.
+
+You normally should use L<Perinci::CmdLine::Any> instead to be able to switch
+backend on the fly.
 
 =for Pod::Coverage ^(BUILD|get_meta|hook_.+|action_.+)$
 
